"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = void 0;
const chalk_1 = __importDefault(require("chalk"));
const moment_1 = __importDefault(require("moment"));
var logger;
(function (logger) {
    const icon = (() => {
        const isSupported = process.platform !== 'win32' || process.env.CI || process.env.TERM === 'xterm-256color';
        return {
            info: isSupported ? 'ℹ' : 'i',
            success: isSupported ? '✔' : '√',
            warning: isSupported ? '⚠' : '!',
            error: isSupported ? '✖' : '×',
        };
    })();
    const colorDict = {
        info: 'blue',
        success: 'green',
        warning: 'yellow',
        error: 'red',
    };
    let isLogShown = true;
    function showLog(show) {
        isLogShown = show;
    }
    logger.showLog = showLog;
    /**
     * 清楚行并重新打印自负一层
     * @param str 打印的字符串
     * @param color 颜色
     */
    function logs(str, color = 36) {
        // if (!isLogShown) return
        if (!process.stdout || !process.stdout.writable)
            return;
        process.stdout.write('\x1b[0K'); //清除行
        if (color !== undefined)
            process.stdout.write(`\x1b[${color}m`);
        process.stdout.write(str);
        if (color !== undefined)
            process.stdout.write(`\x1b[0m`);
        process.stdout.write('\x1b[0G'); //回到行首
    }
    logger.logs = logs;
    /**
     * 换行打印字符串
     * @param str 打印的字符串
     */
    function logln(str) {
        // if (!isLogShown) return
        if (!process.stdout || !process.stdout.writable)
            return;
        process.stdout.write('\x1b[0K'); //清除行
        process.stdout.write(str);
        process.stdout.write('\n');
    }
    logger.logln = logln;
    /**
     * 清除行
     */
    function clearLine() {
        process.stdout.write(`\x1b[0G\x1b[0K`);
    }
    logger.clearLine = clearLine;
    function success(tag, msg) {
        outLog(tag, 'success', msg);
    }
    logger.success = success;
    function info(tag, msg) {
        outLog(tag, 'info', msg);
    }
    logger.info = info;
    function warn(tag, msg) {
        outLog(tag, 'warning', msg);
    }
    logger.warn = warn;
    function error(tag, msg) {
        outLog(tag, 'error', msg);
    }
    logger.error = error;
    /**
     * 输出值
     * @param vals 要输出的值
     */
    function out(...vals) {
        if (isLogShown)
            console.log(vals);
    }
    logger.out = out;
    function outLog(tag, type, msg) {
        if (!isLogShown)
            return;
        const colorName = colorDict[type];
        const time = (0, moment_1.default)().format('YYYY-MM-DD HH:mm:ss');
        console.log(''
            + chalk_1.default[colorName](time) + ' '
            + chalk_1.default.bold[colorName](icon[type]) + ' '
            + chalk_1.default.bold[colorName]('[' + tag + ']') + ' '
            + chalk_1.default[colorName](msg));
    }
})(logger = exports.logger || (exports.logger = {}));
