"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCryptStream = void 0;
const stream_1 = __importDefault(require("stream"));
/**
 * 创建加解密流
 * @param password 密码
 * @returns 加解密流
 */
function createCryptStream(password) {
    let index = 0;
    return new stream_1.default.Transform({
        transform(chunk, encoding, callback) {
            //没有密码则不管
            if (!password || !password.length)
                return callback(null, chunk);
            //只允许字符串和Buffer
            if (typeof chunk == 'string')
                chunk = Buffer.from(chunk);
            else if (!(chunk instanceof Buffer))
                throw new Error('Encrypt database data error [NOT_BUFFER]');
            //加密
            const buffer = Buffer.alloc(chunk.length);
            const _password = (password instanceof Buffer) ? password : Buffer.from(password);
            for (let i = 0; i < buffer.length; i++, index++) {
                buffer[i] = chunk[i] ^ _password[index % _password.length];
            }
            //完成
            callback(null, buffer);
        }
    });
}
exports.createCryptStream = createCryptStream;
